Open Job Description model library for Rust.
Provides parsing, validation, and job creation for OpenJD templates conforming to the 2023-09 specification.
Re-exports
pub use job::create_job;pub use job::step_dependency_graph;pub use job::step_param_space;pub use error::ModelError;pub use error::DiagnosticSpan;pub use error::ErrorDetail;pub use error::PathElement;pub use error::ValidationError;pub use error::ValidationErrors;pub use job::create_job::build_symbol_table;pub use job::create_job::convert_environment;pub use job::create_job::create_job;pub use job::create_job::evaluate_let_bindings;pub use job::create_job::merge_job_parameter_definitions;pub use job::create_job::preprocess_job_parameters;pub use job::create_job::MergedParameterDefinition;pub use job::create_job::PathParameterOptions;pub use step_dependency_graph::StepDependencyGraph;pub use step_param_space::StepParameterSpaceIterator;pub use template::parse::decode_environment_template;pub use template::parse::decode_job_template;pub use template::parse::decode_template;pub use template::parse::DecodedTemplate;pub use template::parse::DocumentType;pub use types::CallerLimits;pub use types::DataFlow;pub use types::EndOfLine;pub use types::Extensions;pub use types::FileType;pub use types::JobParameterInputValues;pub use types::JobParameterType;pub use types::JobParameterValue;pub use types::JobParameterValues;pub use types::ModelExtension;pub use types::ModelProfile;pub use types::ObjectType;pub use types::SpecificationRevision;pub use types::TaskParameterSet;pub use types::TaskParameterType;pub use types::TaskParameterValue;pub use types::TemplateSpecificationVersion;pub use types::ValidationContext;
Modules
- capabilities
- Standard capability definitions for the Open Job Description specification.
- error
- Error types for the OpenJD model library.
- format_
string - Format string parsing and resolution.
- job
- Instantiated job types — the result of
create_job(). - symbol_
table - Hierarchical symbol table for expression evaluation.
- template
- v2023-09 schema model types.
- types
- Core types shared across specification versions.
Structs
- Format
String - Symbol
Table - Hierarchical symbol table mapping names to values or nested tables.