Standard capability definitions for the Open Job Description specification.
Capability lookup functions take (SpecificationRevision, &Extensions) and
return Result because the set of standard capabilities may vary by revision,
and future extensions may add or modify capabilities that are only valid for
certain revision+extension combinations.
Functions
- standard_
amount_ capability_ names - Return the standard amount capability names for the given revision and extensions.
- standard_
attribute_ capabilities - Return the standard attribute capabilities (name + allowed values) for the given revision and extensions.
- standard_
attribute_ capability_ names - Return the standard attribute capability names for the given revision and extensions.
- validate_
amount_ capability_ name - Validate that a string is a valid amount capability name.
- validate_
attribute_ capability_ name - Validate that a string is a valid attribute capability name.