Module parse

Module parse 

Template parsing: YAML/JSON decoding and dispatch by specificationVersion.

Mirrors Python _parse.py.

Enums

DecodedTemplate
Auto-detect template type and decode.
DocumentType
Document format.

Constants

MAX_DOCUMENT_DEPTH
Maximum structural nesting depth for template documents.

Functions

decode_environment_template
Decode and validate an environment template from a YAML value.
decode_job_template
Decode and validate a job template from a YAML value.
decode_template
Auto-detect whether a template is a job or environment template and decode it.
document_string_to_object
Parse a string into a generic YAML/JSON object.