Template parsing: YAML/JSON decoding and dispatch by specificationVersion.
Mirrors Python _parse.py.
Enums
- Decoded
Template - Auto-detect template type and decode.
- Document
Type - Document format.
Constants
- MAX_
DOCUMENT_ DEPTH - Maximum structural nesting depth for template documents.
Functions
- decode_
environment_ template - Decode and validate an environment template from a YAML value.
- decode_
job_ template - Decode and validate a job template from a YAML value.
- decode_
template - Auto-detect whether a template is a job or environment template and decode it.
- document_
string_ to_ object - Parse a string into a generic YAML/JSON object.